package com.ruoyi.project.apply.service.impl;

import com.ruoyi.project.apply.domain.TApplyLock;
import com.ruoyi.project.apply.mapper.TApplyLockMapper;
import com.ruoyi.project.apply.service.ITApplyLockService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 破锁管理Service业务层处理
 *
 * @author ruoyi
 * @date 2023-03-06
 */
@Service
public class TApplyLockServiceImpl implements ITApplyLockService
{
    @Autowired
    private TApplyLockMapper tApplyLockMapper;

    /**
     * 查询破锁管理
     *
     * @param id 破锁管理ID
     * @return 破锁管理
     */
    @Override
    public TApplyLock selectTApplyLockById(Long id)
    {
        return tApplyLockMapper.selectTApplyLockById(id);
    }
    public TApplyLock selectTApplyLockByLockCode(String lockCode)
    {
        return tApplyLockMapper.selectTApplyLockByLockCode(lockCode);
    }

    /**
     * 查询破锁管理列表
     *
     * @param tApplyLock 破锁管理
     * @return 破锁管理
     */
    @Override
    public List<TApplyLock> selectTApplyLockList(TApplyLock tApplyLock)
    {
        return tApplyLockMapper.selectTApplyLockList(tApplyLock);
    }
    @Override
    public List<TApplyLock> selectTApplyLockPidList(TApplyLock tApplyLock)
    {
        return tApplyLockMapper.selectTApplyLockPidList(tApplyLock);
    }

    /**
     * 新增破锁管理
     *
     * @param tApplyLock 破锁管理
     * @return 结果
     */
    @Override
    public int insertTApplyLock(TApplyLock tApplyLock)
    {
        return tApplyLockMapper.insertTApplyLock(tApplyLock);
    }

    /**
     * 修改破锁管理
     *
     * @param tApplyLock 破锁管理
     * @return 结果
     */
    @Override
    public int updateTApplyLock(TApplyLock tApplyLock)
    {
        return tApplyLockMapper.updateTApplyLock(tApplyLock);
    }

    /**
     * 批量删除破锁管理
     *
     * @param ids 需要删除的破锁管理ID
     * @return 结果
     */
    @Override
    public int deleteTApplyLockByIds(Long[] ids)
    {
        return tApplyLockMapper.deleteTApplyLockByIds(ids);
    }

    /**
     * 删除破锁管理信息
     *
     * @param id 破锁管理ID
     * @return 结果
     */
    @Override
    public int deleteTApplyLockById(Long id)
    {
        return tApplyLockMapper.deleteTApplyLockById(id);
    }
}
